@@ -1,7 +1,7 @@
 """Communicates with databases using repository pattern and service patterns"""
 
 
-__version__ = '0.4.0'
+__version__ = '0.4.1'
 
 
 from dbdaora.cache import CacheType
@@ -26,7 +26,7 @@ from dbdaora.sorted_set.entity import (
     SortedSetEntity,
 )
 from dbdaora.sorted_set.query import SortedSetQuery
-from dbdaora.sorted_set.repository import SortedSetRepository
+from dbdaora.sorted_set.repositories import SortedSetRepository
 
 
 try:
